==> PathOfBuilding-1.4.155.zip: Data/Uniques/dagger.lua <==
-- Item data (c) Grinding Gear Games

return {
-- Weapon: Dagger
[[
Arakaali's Fang
Fiend Dagger
Variant: Pre 2.6.0
Variant: {2_6}Pre 3.5.0
Variant: Current
Requires Level 53, 58 Dex, 123 Int
40% increased Global Critical Strike Chance
{variant:1,2}20% chance to Trigger Level 1 Raise Spiders on Kill
{variant:3}100% chance to Trigger Level 1 Raise Spiders on Kill
(170-200)% increased Physical Damage
Adds (8-13) to (20-30) Physical Damage
Adds 1 to 59 Chaos Damage
15% chance to Poison on Hit
]],[[
Bino's Kitchen Knife
Slaughter Knife
Variant: Pre 2.2.0
Variant: Current
Requires Level 65, 81 Dex, 117 Int
30% increased Global Critical Strike Chance
30% increased Damage over Time
Adds (50-60) to (120-140) Physical Damage
(40-50)% increased Critical Strike Chance
{variant:1}+(10-15)% to Global Critical Strike Multiplier
{variant:2}+(15-25)% to Global Critical Strike Multiplier
+(8-12)% to Chaos Resistance
On Killing a Poisoned Enemy, nearby Enemies are Poisoned
and nearby Allies Regenerate 200 Life per second
]],[[
Bloodplay
Stiletto
Variant: Pre 2.6.0
Variant: Current
Requires Level 15, 30 Dex, 30 Int
30% increased Global Critical Strike Chance
+20 to Dexterity
(20-40)% increased Physical Damage
Adds (3-6) to (9-13) Physical Damage
10% increased Attack Speed
Extra Gore
{variant:1}10% chance to cause Bleeding on Hit
{variant:2}30% chance to cause Bleeding on Hit
]],[[
The Consuming Dark
Fiend Dagger
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 53, 58 Dex, 123 Int
40% increased Global Critical Strike Chance
+1 to Level of all Fire Spell Skill Gems
{variant:1,2}(40-60)% increased Spell Damage
{variant:3}(40-60)% increased Fire Damage
+(20-40) to Intelligence
{variant:1}45% of Fire Damage Converted to Chaos Damage
{variant:2,3}30% of Fire Damage Converted to Chaos Damage
{variant:1,2}Your Chaos Damage Poisons Enemies
{variant:3}Your Chaos Damage has 60% chance to Poison Enemies
]],[[
Divinarius
Imperial Skean
League: Legion
Source: Drops from normal{Templar} legion
Variant: Pre 3.7.0
Variant: Current
Requires Level 66, 95 Dex, 131 Int
30% increased Global Critical Strike Chance
(50-70)% increased Spell Damage
{variant:1}(80-100)% increased Critical Strike Chance for Spells
{variant:1}+10 Life gained on Kill
{variant:2}+30 Life gained on Kill
{variant:1}+5 Mana gained on Kill
{variant:2}+10 Mana gained on Kill
10% increased Area of Effect of Area Skills
{variant:2}(125-175)% increased Critical Strike Chance for Spells if you've Killed Recently
{variant:2}+(40-60)% to Critical Strike Multiplier for Spells if you haven't Killed Recently
]],[[
Goredrill
Skinning Knife
Upgrade: Upgrades to unique{Sanguine Gambol} via prophecy{Crimson Hues}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 5, 16 Dex
30% increased Global Critical Strike Chance
+(10-15) to Dexterity
(50-70)% increased Physical Damage
Adds (1-2) to (3-5) Physical Damage
30% increased Critical Strike Chance
{variant:1}Melee Critical Strikes cause Bleeding
{variant:2}50% chance to cause Bleeding with Melee Critical Strikes with this Weapon
40% increased Attack Damage against Bleeding Enemies
]],[[
Sanguine Gambol
Skinning Knife
Source: Upgraded from unique{Goredrill} via prophecy{Crimson Hues}
Requires Level 59
30% increased Global Critical Strike Chance
(50-70)% increased Physical Damage
Adds (70-85) to (110-118) Physical Damage
+(10-15) to Dexterity
30% increased Critical Strike Chance
50% chance to cause Bleeding on Critical Strike
40% increased Attack Damage against Bleeding Enemies
You have Crimson Dance if you have dealt a Critical Strike Recently
]],[[
Heartbreaker
Royal Skean
Variant: Pre 2.6.0
Variant: Current
Requires Level 50, 71 Dex, 102 Int
30% increased Global Critical Strike Chance
{variant:1}(40-50)% increased Spell Damage
{variant:2}(60-70)% increased Spell Damage
+(40-50) to maximum Mana
+50 to maximum Energy Shield
10% faster start of Energy Shield Recharge
Your Spells have Culling Strike
]],[[
Mark of the Doubting Knight
Platinum Kris
Variant: Pre 2.0.0
Variant: Pre 2.6.0
Variant: Current
Requires Level 64, 76 Dex, 149 Int
50% increased Global Critical Strike Chance
5% Additional Chance to Block while Dual Wielding
{variant:1}(180-210)% increased Physical Damage
{variant:2}(210-240)% increased Physical Damage
{variant:3}(250-270)% increased Physical Damage
10% reduced Attack Speed
+(6-10)% to all Elemental Resistances
{variant:1,2}Melee Critical Strikes have 25% chance to cause Bleeding
{variant:3}50% chance to Cause Bleeding on Critical Strike
{variant:1,2}Melee Critical Strikes have 25% chance to Poison the Enemy
{variant:3}50% chance to Cause Poison on Critical Strike
]],[[
Mightflay
Flaying Knife
Requires Level 35, 73 Dex, 51 Int
30% increased Global Critical Strike Chance
(80-100)% increased Physical Damage
Adds 12 to 24 Physical Damage
+25 to Strength
+10 Life gained for each Enemy hit by your Attacks
]],[[
Taproot
Ambusher
Requires Level 60, 113 Dex, 113 Int
30% increased Global Critical Strike Chance
(180-200)% increased Physical Damage
(10-15)% increased Attack Speed
(15-20)% increased Poison Duration
0.5% of Attack Damage Leeched as Mana against Poisoned Enemies
0.5% of Attack Damage Leeched as Life against Maimed Enemies
(15-20)% chance to Maim on Hit
20% chance to Poison on Hit
]],[[
Ungil's Gauche
Boot Knife
Variant: Pre 1.1.0
Variant: Pre 1.3.0
Variant: Current
Requires Level 20, 31 Dex, 45 Int
30% increased Global Critical Strike Chance
{variant:2}20% additional Chance to Block while Dual Wielding
{variant:1,3}12% additional Chance to Block while Dual Wielding
(80-100)% increased Physical Damage
+(10-20) to Dexterity
Adds 3 to 30 Lightning Damage
10% increased Attack Speed
50% increased Global Critical Strike Chance
]],[[
Vulconus
Demon Dagger
Variant: Pre 3.5.0
Variant: Current
Source: Drops from unique{The Enslaver} (Tier 11+)
Requires Level 68
40% increased Global Critical Strike Chance 
Adds (85-110) to (130-150) Physical Damage
Adds (130-160) to (220-240) Fire Damage
{variant:2}50% chance to cause Bleeding on Hit
{variant:1}Attacks with this Weapon deal (80-100) to (160-200) added Fire Damage to Bleeding Enemies 
{variant:1}Attacks with this Weapon deal (80-100) to (160-200) added Physical Damage to Ignited Enemies 
{variant:1}Attacks with this Weapon have 25% chance to inflict Bleeding against Ignited Enemies 
{variant:2}(75-100)% increased Fire Damage with Hits and Ailments against Bleeding Enemies
{variant:2}(75-100)% increased Physical Damage with Hits and Ailments against Ignited Enemies
Every 8 seconds, gain Avatar of Fire for 4 seconds 
{variant:1}(80-120)% increased Critical Strike Chance while you have Avatar of Fire 
{variant:2}(160-200)% increased Critical Strike Chance while you have Avatar of Fire 
50% of Physical Damage Converted to Fire while you have Avatar of Fire 
{variant:1}+1000 Armour while you do not have Avatar of Fire
{variant:2}+2000 Armour while you do not have Avatar of Fire
]],[[
White Wind
Imperial Skean
Requires Level 66
30% increased Global Critical Strike Chance
Adds (160-190) to (280-320) Cold Damage
(10-15)% increased Attack Speed
+(300-400) to Evasion Rating
20% chance to Dodge Attacks while your Off Hand is empty
100% increased Cold Damage while your Off Hand is empty
]],[[
Widowmaker
Boot Blade
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 44, 63 Dex, 90 Int
30% increased Global Critical Strike Chance
{variant:1}Adds (15-25) to (35-45) Physical Damage
{variant:2}Adds (35-40) to (55-60) Physical Damage
(22-30)% increased Critical Strike Chance
+(30-40)% to Global Critical Strike Multiplier
100% increased Critical Strike Chance against Enemies on Full Life
1% of Attack Damage Leeched as Life on Critical Strike
]],
}

==> PathOfBuilding-1.4.168.zip: Data/Uniques/dagger.lua <==
-- Item data (c) Grinding Gear Games

return {
-- Weapon: Dagger
[[
Arakaali's Fang
Fiend Dagger
Variant: Pre 2.6.0
Variant: {2_6}Pre 3.5.0
Variant: Current
Requires Level 53, 58 Dex, 123 Int
Implicits: 1
40% increased Global Critical Strike Chance
{variant:1,2}20% chance to Trigger Level 1 Raise Spiders on Kill
{variant:3}100% chance to Trigger Level 1 Raise Spiders on Kill
(170-200)% increased Physical Damage
Adds (8-13) to (20-30) Physical Damage
Adds 1 to 59 Chaos Damage
15% chance to Poison on Hit
]],[[
Bino's Kitchen Knife
Slaughter Knife
Variant: Pre 2.2.0
Variant: Current
Requires Level 65, 81 Dex, 117 Int
Implicits: 1
30% increased Global Critical Strike Chance
30% increased Damage over Time
Adds (50-60) to (120-140) Physical Damage
(40-50)% increased Critical Strike Chance
{variant:1}+(10-15)% to Global Critical Strike Multiplier
{variant:2}+(15-25)% to Global Critical Strike Multiplier
+(8-12)% to Chaos Resistance
On Killing a Poisoned Enemy, nearby Enemies are Poisoned
and nearby Allies Regenerate 200 Life per second
]],[[
Bloodplay
Stiletto
Variant: Pre 2.6.0
Variant: Current
Requires Level 15, 30 Dex, 30 Int
Implicits: 1
30% increased Global Critical Strike Chance
+20 to Dexterity
(20-40)% increased Physical Damage
Adds (3-6) to (9-13) Physical Damage
10% increased Attack Speed
Extra Gore
{variant:1}10% chance to cause Bleeding on Hit
{variant:2}30% chance to cause Bleeding on Hit
]],[[
The Consuming Dark
Fiend Dagger
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 53, 58 Dex, 123 Int
Implicits: 1
40% increased Global Critical Strike Chance
+1 to Level of all Fire Spell Skill Gems
{variant:1,2}(40-60)% increased Spell Damage
{variant:3}(40-60)% increased Fire Damage
+(20-40) to Intelligence
{variant:1}45% of Fire Damage Converted to Chaos Damage
{variant:2,3}30% of Fire Damage Converted to Chaos Damage
{variant:1,2}Your Chaos Damage Poisons Enemies
{variant:3}Your Chaos Damage has 60% chance to Poison Enemies
]],[[
Divinarius
Imperial Skean
League: Legion
Source: Drops from normal{Templar} legion
Variant: Pre 3.7.0
Variant: Current
Requires Level 66, 95 Dex, 131 Int
Implicits: 1
30% increased Global Critical Strike Chance
(50-70)% increased Spell Damage
{variant:1}(80-100)% increased Critical Strike Chance for Spells
{variant:1}+10 Life gained on Kill
{variant:2}+30 Life gained on Kill
{variant:1}+5 Mana gained on Kill
{variant:2}+10 Mana gained on Kill
10% increased Area of Effect of Area Skills
{variant:2}(125-175)% increased Critical Strike Chance for Spells if you've Killed Recently
{variant:2}+(40-60)% to Critical Strike Multiplier for Spells if you haven't Killed Recently
]],[[
Goredrill
Skinning Knife
Upgrade: Upgrades to unique{Sanguine Gambol} via prophecy{Crimson Hues}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 5, 16 Dex, 11 Int
Implicits: 1
30% increased Global Critical Strike Chance
+(10-15) to Dexterity
(50-70)% increased Physical Damage
Adds (1-2) to (3-5) Physical Damage
30% increased Critical Strike Chance
{variant:1}Melee Critical Strikes cause Bleeding
{variant:2}50% chance to cause Bleeding with Melee Critical Strikes with this Weapon
40% increased Attack Damage against Bleeding Enemies
]],[[
Sanguine Gambol
Skinning Knife
Source: Upgraded from unique{Goredrill} via prophecy{Crimson Hues}
Requires Level 59, 16 Dex, 11 Int
Implicits: 1
30% increased Global Critical Strike Chance
(50-70)% increased Physical Damage
Adds (70-85) to (110-118) Physical Damage
+(10-15) to Dexterity
30% increased Critical Strike Chance
50% chance to cause Bleeding on Critical Strike
40% increased Attack Damage against Bleeding Enemies
You have Crimson Dance if you have dealt a Critical Strike Recently
]],[[
Heartbreaker
Royal Skean
Variant: Pre 2.6.0
Variant: Current
Requires Level 50, 71 Dex, 102 Int
Implicits: 1
30% increased Global Critical Strike Chance
{variant:1}(40-50)% increased Spell Damage
{variant:2}(60-70)% increased Spell Damage
+(40-50) to maximum Mana
+50 to maximum Energy Shield
10% faster start of Energy Shield Recharge
Your Spells have Culling Strike
]],[[
Mark of the Doubting Knight
Platinum Kris
Variant: Pre 2.0.0
Variant: Pre 2.6.0
Variant: Current
Requires Level 64, 76 Dex, 149 Int
Implicits: 1
50% increased Global Critical Strike Chance
5% Additional Chance to Block while Dual Wielding
{variant:1}(180-210)% increased Physical Damage
{variant:2}(210-240)% increased Physical Damage
{variant:3}(250-270)% increased Physical Damage
10% reduced Attack Speed
+(6-10)% to all Elemental Resistances
{variant:1,2}Melee Critical Strikes have 25% chance to cause Bleeding
{variant:3}50% chance to Cause Bleeding on Critical Strike
{variant:1,2}Melee Critical Strikes have 25% chance to Poison the Enemy
{variant:3}50% chance to Cause Poison on Critical Strike
]],[[
Mightflay
Flaying Knife
Requires Level 35, 73 Dex, 51 Int
Implicits: 1
30% increased Global Critical Strike Chance
(80-100)% increased Physical Damage
Adds 12 to 24 Physical Damage
+25 to Strength
+10 Life gained for each Enemy hit by your Attacks
]],[[
Taproot
Ambusher
Requires Level 60, 113 Dex, 113 Int
Implicits: 1
30% increased Global Critical Strike Chance
(180-200)% increased Physical Damage
(10-15)% increased Attack Speed
(15-20)% increased Poison Duration
0.5% of Attack Damage Leeched as Mana against Poisoned Enemies
0.5% of Attack Damage Leeched as Life against Maimed Enemies
(15-20)% chance to Maim on Hit
20% chance to Poison on Hit
]],[[
Ungil's Gauche
Boot Knife
Variant: Pre 1.1.0
Variant: Pre 1.3.0
Variant: Current
Requires Level 20, 31 Dex, 45 Int
Implicits: 1
30% increased Global Critical Strike Chance
{variant:2}20% additional Chance to Block while Dual Wielding
{variant:1,3}12% additional Chance to Block while Dual Wielding
(80-100)% increased Physical Damage
+(10-20) to Dexterity
Adds 3 to 30 Lightning Damage
10% increased Attack Speed
50% increased Global Critical Strike Chance
]],[[
Vulconus
Demon Dagger
Variant: Pre 3.5.0
Variant: Current
Source: Drops from unique{The Enslaver} (Tier 11+)
Requires Level 68, 76 Dex, 149 Int
Implicits: 1
40% increased Global Critical Strike Chance 
Adds (85-110) to (130-150) Physical Damage
Adds (130-160) to (220-240) Fire Damage
{variant:2}50% chance to cause Bleeding on Hit
{variant:1}Attacks with this Weapon deal (80-100) to (160-200) added Fire Damage to Bleeding Enemies 
{variant:1}Attacks with this Weapon deal (80-100) to (160-200) added Physical Damage to Ignited Enemies 
{variant:1}Attacks with this Weapon have 25% chance to inflict Bleeding against Ignited Enemies 
{variant:2}(75-100)% increased Fire Damage with Hits and Ailments against Bleeding Enemies
{variant:2}(75-100)% increased Physical Damage with Hits and Ailments against Ignited Enemies
Every 8 seconds, gain Avatar of Fire for 4 seconds 
{variant:1}(80-120)% increased Critical Strike Chance while you have Avatar of Fire 
{variant:2}(160-200)% increased Critical Strike Chance while you have Avatar of Fire 
50% of Physical Damage Converted to Fire while you have Avatar of Fire 
{variant:1}+1000 Armour while you do not have Avatar of Fire
{variant:2}+2000 Armour while you do not have Avatar of Fire
]],[[
White Wind
Imperial Skean
Requires Level 66, 95 Dex, 131 Int
Implicits: 1
30% increased Global Critical Strike Chance
Adds (160-190) to (280-320) Cold Damage
(10-15)% increased Attack Speed
+(300-400) to Evasion Rating
20% chance to Dodge Attacks while your Off Hand is empty
100% increased Cold Damage while your Off Hand is empty
]],[[
Widowmaker
Boot Blade
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 44, 63 Dex, 90 Int
Implicits: 1
30% increased Global Critical Strike Chance
{variant:1}Adds (15-25) to (35-45) Physical Damage
{variant:2}Adds (35-40) to (55-60) Physical Damage
(22-30)% increased Critical Strike Chance
+(30-40)% to Global Critical Strike Multiplier
100% increased Critical Strike Chance against Enemies on Full Life
1% of Attack Damage Leeched as Life on Critical Strike
]],
}
